@@ -30,13 +30,9 @@
 
 #include "panel-applets-manager-dbus.h"
 
-G_DEFINE_TYPE_WITH_CODE (PanelAppletsManagerDBus,
-			 panel_applets_manager_dbus,
-			 PANEL_TYPE_APPLETS_MANAGER,
-			 g_io_extension_point_implement (PANEL_APPLETS_MANAGER_EXTENSION_POINT_NAME,
-							 g_define_type_id,
-							 "dbus",
-							 10))
+G_DEFINE_TYPE (PanelAppletsManagerDBus,
+               panel_applets_manager_dbus,
+               PANEL_TYPE_APPLETS_MANAGER)
 
 struct _PanelAppletsManagerDBusPrivate
 {
@@ -60,7 +56,6 @@ typedef struct _PanelAppletFactoryInfo {
 	gchar              *srcdir;
 
 	GList              *applet_list;
-	gboolean            has_old_ids;
 } PanelAppletFactoryInfo;
 
 #define PANEL_APPLET_FACTORY_GROUP "Applet Factory"
@@ -94,7 +89,6 @@ _panel_applets_manager_get_applet_info (GKeyFile    *applet_file,
 	char             *name;
 	char             *comment;
 	char             *icon;
-	char            **old_ids;
 
 	iid = g_strdup_printf ("%s::%s", factory_id, group);
 	name = g_key_file_get_locale_string (applet_file, group,
@@ -102,17 +96,13 @@ _panel_applets_manager_get_applet_info (GKeyFile    *applet_file,
 	comment = g_key_file_get_locale_string (applet_file, group,
 						"Description", NULL, NULL);
 	icon = g_key_file_get_string (applet_file, group, "Icon", NULL);
-	/* Bonobo compatibility */
-	old_ids = g_key_file_get_string_list (applet_file, group,
-					      "BonoboId", NULL, NULL);
 
-	info = panel_applet_info_new (iid, name, comment, icon, (const char **) old_ids);
+	info = panel_applet_info_new (iid, name, comment, icon);
 
 	g_free (iid);
 	g_free (name);
 	g_free (comment);
 	g_free (icon);
-	g_strfreev (old_ids);
 
 	return info;
 }
@@ -161,9 +151,12 @@ panel_applets_manager_get_applet_factory_info_from_file (const gchar *filename)
 
 			return NULL;
 		}
-	}
+	} else {
+		panel_applet_factory_info_free (info);
+		g_key_file_free (applet_file);
 
-	info->has_old_ids = FALSE;
+		return NULL;
+	}
 
 	groups = g_key_file_get_groups (applet_file, &n_groups);
 	for (i = 0; i < n_groups; i++) {
@@ -174,8 +167,6 @@ panel_applets_manager_get_applet_factory_info_from_file (const gchar *filename)
 
 		ainfo = _panel_applets_manager_get_applet_info (applet_file,
 								groups[i], info->id);
-		if (panel_applet_info_get_old_ids (ainfo) != NULL)
-			info->has_old_ids = TRUE;
 
 		info->applet_list = g_list_prepend (info->applet_list, ainfo);
 	}
@@ -527,47 +518,6 @@ panel_applets_manager_dbus_get_applet_info (PanelAppletsManager *manager,
 	return NULL;
 }
 
-static PanelAppletInfo *
-panel_applets_manager_dbus_get_applet_info_from_old_id (PanelAppletsManager *manager,
-							const gchar         *iid)
-{
-	PanelAppletsManagerDBus *dbus_manager = PANEL_APPLETS_MANAGER_DBUS (manager);
-
-	GHashTableIter iter;
-	gpointer       key, value;
-
-	g_hash_table_iter_init (&iter, dbus_manager->priv->applet_factories);
-	while (g_hash_table_iter_next (&iter, &key, &value)) {
-		PanelAppletFactoryInfo *info;
-		GList                  *l;
-
-		info = (PanelAppletFactoryInfo *) value;
-		if (!info->has_old_ids)
-			continue;
-
-		for (l = info->applet_list; l; l = g_list_next (l)) {
-			PanelAppletInfo *ainfo;
-			gint             i = 0;
-			const gchar * const *old_ids;
-
-			ainfo = (PanelAppletInfo *) l->data;
-
-			old_ids = panel_applet_info_get_old_ids (ainfo);
-
-			if (old_ids == NULL)
-				continue;
-
-			while (old_ids[i]) {
-				if (g_strcmp0 (old_ids[i], iid) == 0)
-					return ainfo;
-				i++;
-			}
-		}
-	}
-
-	return NULL;
-}
-
 static gboolean
 panel_applets_manager_dbus_load_applet (PanelAppletsManager         *manager,
 					const gchar                 *iid,
@@ -590,6 +540,13 @@ panel_applets_manager_dbus_get_applet_widget (PanelAppletsManager *manager,
 	return info->get_applet_widget (info->id, uid);
 }
 
+static gchar *
+panel_applets_manager_dbus_get_new_iid (PanelAppletsManager *manager,
+                                        const gchar         *old_iid)
+{
+	return NULL;
+}
+
 static void
 panel_applets_manager_dbus_finalize (GObject *object)
 {
@@ -636,9 +593,9 @@ panel_applets_manager_dbus_class_init (PanelAppletsManagerDBusClass *class)
 	manager_class->factory_activate = panel_applets_manager_dbus_factory_activate;
 	manager_class->factory_deactivate = panel_applets_manager_dbus_factory_deactivate;
 	manager_class->get_applet_info = panel_applets_manager_dbus_get_applet_info;
-	manager_class->get_applet_info_from_old_id = panel_applets_manager_dbus_get_applet_info_from_old_id;
 	manager_class->load_applet = panel_applets_manager_dbus_load_applet;
 	manager_class->get_applet_widget = panel_applets_manager_dbus_get_applet_widget;
+	manager_class->get_new_iid = panel_applets_manager_dbus_get_new_iid;
 
 	g_type_class_add_private (class, sizeof (PanelAppletsManagerDBusPrivate));
 }
