@@ -34,13 +34,6 @@
 
 #include <string.h>
 
-#if defined(HAVE_CRT_EXTERNS_H) && defined(HAVE__NSGETENVIRON)
-#include <crt_externs.h> /* for _NSGetEnviron */
-#define environ (*_NSGetEnviron())
-#else
-extern char **environ;
-#endif
-
 static int            screens     = 0;
 static int           *monitors    = NULL;
 static GdkRectangle **geometries  = NULL;
@@ -49,7 +42,6 @@ static gboolean       have_randr  = FALSE;
 static gboolean       have_randr_1_3 = FALSE;
 static guint          reinit_id   = 0;
 
-#ifdef HAVE_RANDR
 static gboolean
 _panel_multiscreen_output_should_be_first (Display       *xdisplay,
 					   RROutput       output,
@@ -90,14 +82,12 @@ _panel_multiscreen_output_should_be_first (Display       *xdisplay,
 	 */
 	return (g_ascii_strncasecmp (info->name, "LVDS", strlen ("LVDS")) == 0);
 }
-#endif
 
 static gboolean
 panel_multiscreen_get_randr_monitors_for_screen (GdkScreen     *screen,
 						 int           *monitors_ret,
 						 GdkRectangle **geometries_ret)
 {
-#ifdef HAVE_RANDR
 	Display            *xdisplay;
 	Window              xroot;
 	XRRScreenResources *resources;
@@ -135,7 +125,6 @@ panel_multiscreen_get_randr_monitors_for_screen (GdkScreen     *screen,
 	xdisplay = GDK_SCREEN_XDISPLAY (screen);
 	xroot = GDK_WINDOW_XID (gdk_screen_get_root_window (screen));
 
-#if (RANDR_MAJOR > 1 || (RANDR_MAJOR == 1 && RANDR_MINOR >= 3))
 	if (have_randr_1_3) {
 		resources = XRRGetScreenResourcesCurrent (xdisplay, xroot);
 		if (resources->noutput == 0) {
@@ -148,18 +137,13 @@ panel_multiscreen_get_randr_monitors_for_screen (GdkScreen     *screen,
 		}
 	} else
 		resources = XRRGetScreenResources (xdisplay, xroot);
-#else
-	resources = XRRGetScreenResources (xdisplay, xroot);
-#endif
 
 	if (!resources)
 		return FALSE;
 
 	primary = None;
-#if (RANDR_MAJOR > 1 || (RANDR_MAJOR == 1 && RANDR_MINOR >= 3))
 	if (have_randr_1_3)
 		primary = XRRGetOutputPrimary (xdisplay, xroot);
-#endif
 
 	geometries = g_array_sized_new (FALSE, FALSE,
 					sizeof (GdkRectangle),
@@ -228,9 +212,6 @@ panel_multiscreen_get_randr_monitors_for_screen (GdkScreen     *screen,
 	*geometries_ret = (GdkRectangle *) g_array_free (geometries, FALSE);
 
 	return TRUE;
-#else
-	return FALSE;
-#endif
 }
 
 static void
@@ -412,15 +393,12 @@ panel_multiscreen_queue_reinit (void)
 static void
 panel_multiscreen_init_randr (GdkDisplay *display)
 {
-#ifdef HAVE_RANDR
 	Display *xdisplay;
 	int      event_base, error_base;
-#endif
 
 	have_randr = FALSE;
 	have_randr_1_3 = FALSE;
 
-#ifdef HAVE_RANDR
 	xdisplay = GDK_DISPLAY_XDISPLAY (display);
 
 	/* We don't remember the event/error bases, as we expect to get "screen
@@ -437,7 +415,6 @@ panel_multiscreen_init_randr (GdkDisplay *display)
 		if ((major == 1 && minor >= 3) || major > 1)
 			have_randr_1_3 = TRUE;
 	}
-#endif
 }
 
 void
@@ -733,39 +710,3 @@ panel_multiscreen_is_at_visible_extreme (GdkScreen *screen,
 		}
 	}
 }
-
-char **
-panel_make_environment_for_screen (GdkScreen  *screen,
-				   char      **envp)
-{
-	char **retval = NULL;
-	char  *display_name;
-	int    display_index = -1;
-	int    i, env_len;
-
-	g_return_val_if_fail (GDK_IS_SCREEN (screen), NULL);
-
-	if (envp == NULL)
-		envp = environ;
-
-	for (env_len = 0; envp[env_len]; env_len++)
-		if (strncmp (envp[env_len], "DISPLAY", strlen ("DISPLAY")) == 0)
-			display_index = env_len;
-
-	retval = g_new (char *, env_len + 1);
-	retval[env_len] = NULL;
-
-	display_name = gdk_screen_make_display_name (screen);
-
-	for (i = 0; i < env_len; i++)
-		if (i == display_index)
-			retval[i] = g_strconcat ("DISPLAY=", display_name, NULL);
-		else
-			retval[i] = g_strdup (envp[i]);
-
-	g_assert (i == env_len);
-
-	g_free (display_name);
-
-	return retval;
-}
